Method: RushCheck::HsRandom#random_std
- Defined in:
- lib/rushcheck/random.rb
#random_std(lo = nil, hi = nil) ⇒ Object
random_std requires optionally the bound of random numbers. It returns an array with length 2, where the first component should be a new random number, and the last should be a new random number generator. This method uses the unique standard random generator TheStdGen.
211 212 213 |
# File 'lib/rushcheck/random.rb', line 211 def random_std(lo=nil, hi=nil) random(RushCheck::TheStdGen.instance, lo, hi) end |